<?php
/*
 * Metodo de pago propio de WAO.
 * version 1.0
 * Fecha: 27 de marzo de 2024
 * Actualizado: 15 de mayo de 2024
 * Desarrollado por : Arturo
 * PayB
 * PARA CONFIGURAR BUSCAR: $image_name, $urls, $paths 
*/
if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

/*
 * Código para PayB (Crear Pedido)
 */

add_action('rest_api_init', function () {
    register_rest_route('custom/v1', '/process-order', [
        'methods' => 'POST',
        'callback' => 'new_handle_product_from_shopa',
        'permission_callback' => '__return_true', // Ajusta la seguridad según sea necesario
    ]);
});

// Funcion auxiliar para depurar url de dominio
function new_obtenerDominio($url) {
    $parsedUrl = parse_url($url);
    $host = $parsedUrl['host'] ?? '';

    // Si no se encuentra 'host', puede ser una URL sin esquema.
    if (empty($host)) {
        // Intentamos obtener el host sin el esquema.
        $host = parse_url('http://' . $url)['host'] ?? '';
    }

    return trim($host, '/');
}

// Funcion auxiliar para construir el nombre de la orden
function new_construir_nombre_orden_y_cat($order_id,$url,$path,$ord_o_cat='o'){
	$path = str_replace('/','',$path);
	$path = strtolower($path);
	$url = new_obtenerDominio($url);
	$urls = get_option('payb_settings_urls');
	$url_sufijo = '';
	foreach ($urls as $entry) {
		if ($entry['url'] === $url) {
			$url_sufijo = $entry['suffix'];
			break;
		}
	}
	$names = get_option('payb_settings_countries');
	$name_sufijo = '';
	foreach ($names as $entry) {
		if ($entry['country'] === $url) {
			$name_sufijo = $entry['suffix'];
			break;
		}
	}
	if($ord_o_cat=='o'){
		$retorno = $url_sufijo.$name_sufijo.'-'.$order_id;
	}else{
		$retorno = $url_sufijo.$name_sufijo;
	}
	return $retorno;
}

// Crear el producto con informacion de ShopA
function new_handle_product_from_shopa(WP_REST_Request $request) {
    // Decodificar el cuerpo de la solicitud
    $data = json_decode($request->get_body(), true);
    // Crear un nuevo producto
    $product = new WC_Product_Simple();
	// Construimos el nombre del producto
    //$product->set_name("Order #" .$data['shop_name'].'-'.$data['order_id']); // El nombre del producto será el order_id de ShopA
	$product->set_name(new_construir_nombre_orden_y_cat($data['order_id'],$data['shop_url'],$data['shop_name'],'o'));
    $product->set_status('publish'); // O 'draft' según sea necesario
    $product->set_catalog_visibility('visible'); // O 'hidden'
    //$product->set_description('[info]'); // Inserción de shortcode en la descripción
    $product->set_short_description('[info]'); // Inserción de shortcode en la descripción
	//$product->set_regular_price('19.99');
	$product->set_regular_price($data['total']);
	$product->set_virtual('yes'); 

	/*global $wpdb;
	$image_id = get_option('payb_background_image_id');
	if(is_bool($image_id)){
		$image_name = 'fondo-claro';  // Asegúrate de que este sea el slug correcto del post
		$query = $wpdb->prepare("SELECT ID FROM $wpdb->posts WHERE post_name = %s AND post_type = 'attachment'", $image_name);
		$image_id = $wpdb->get_var($query);
	}*/
	$image_id = get_option('payb_background_image_id');
    $product->set_image_id($image_id);

    // Guardar el producto para obtener su ID
    $product_id = $product->save();

	// Definir la categoría
	//$category_name = 'cat1';
	$category_name =new_construir_nombre_orden_y_cat($data['order_id'],$data['shop_url'],$data['shop_name'],'c');
	$category_id = 0;

	// Verificar si la categoría ya existe
	$category = get_term_by('name', $category_name, 'product_cat');
	if (!$category) {
		// Crear la categoría si no existe
		$new_category = wp_insert_term($category_name, 'product_cat');
		if (!is_wp_error($new_category)) {
			$category_id = $new_category['term_id'];
		}
	} else {
		// Obtener el ID de la categoría existente
		$category_id = $category->term_id;
	}

	// Asignar la categoría al producto
	if ($category_id) {
		wp_set_object_terms($product->get_id(), [$category_id], 'product_cat');
	}

    // Añadir metadatos personalizados 
    update_post_meta($product_id, 'origen_order_number', $data['order_id']);
    update_post_meta($product_id, 'full_name', $data['billing_info']['first_name'] . ' ' . $data['billing_info']['last_name']);
    update_post_meta($product_id, 'total_amount', $data['total']);
    update_post_meta($product_id, 'currency', $data['currency']);
    update_post_meta($product_id, 'email', $data['billing_info']['email']);
    update_post_meta($product_id, 'phone', $data['billing_info']['phone']);
    update_post_meta($product_id, 'address', $data['billing_info']['address_1'] . ', ' . $data['billing_info']['address_2']);
    update_post_meta($product_id, 'origin_shop_url', $data['shop_url']);
    update_post_meta($product_id, 'origin_shop_name', $data['shop_name']);
    update_post_meta($product_id, 'origin_site_id', $data['shop_site_id']);
    update_post_meta($product_id, 'country', $data['billing_info']['country']);
    update_post_meta($product_id, 'path', $data['path']);

    // Generar la URL del producto
    $product_url = get_permalink($product_id);

    // Devolver la URL del producto como respuesta
    return new WP_REST_Response(['checkout_url' => $product_url], 200);
}

// Cambiar la moneda de acuerdo al parametro o metadato currency
function new_set_currency_based_on_product() {
    global $product, $WOOCS;
    if (!empty($product) && isset($WOOCS)) {
        // Obtén el ID del producto actual
        $product_id = $product->get_id();
        // Recupera el metadato 'currency' del producto
        $currency = get_post_meta($product_id, 'currency', true);
        // Si se encontró una moneda, establece la moneda actual a esta moneda
        if (!empty($currency)) {
            $WOOCS->storage->set_val('woocs_current_currency', $currency);
        }
    }
}
add_action('woocommerce_before_single_product', 'new_set_currency_based_on_product');

// Funcion para hacer depuracion
if (!function_exists('depu')) {
	function depu($masdato){
		$dato = get_option('_depu');
		if ($masdato == "*"){
			$dato = "";
		}else{
			$dato .= "|".$masdato;
		}
		update_option('_depu',$dato);
	}
}

// Funcion para traducir pocas cadenas
if (!function_exists('___')) {
	function ___($cadena) {
		if (isset($_COOKIE['site_language'])) {
			$locale = sanitize_text_field($_COOKIE['site_language']);
		}else{
			$locale = get_locale();
		}
		$idioma = substr($locale, 0, 2);
		// Arreglo de traducciones
		$traducciones = get_option('payb_settings_translations');
		// Verificar si el idioma y la cadena existen en el arreglo de traducciones
		if (isset($traducciones[$idioma][$cadena])) {
			return $traducciones[$idioma][$cadena];
		}

		// Si no se encuentra la traducción, devolver la cadena original
		return $cadena;
	}
}
